@@ -8,6 +8,7 @@ from typing import Optional
 from uuid import uuid4
 
 import discord
+from ddtrace import tracer
 from discord.ext.commands import Bot, errors
 from discord_slash import SlashCommand, context
 from expiringdict import ExpiringDict
@@ -19,6 +20,7 @@ from .errors import (
     UserUnverifiedError,
     UserVerifiedError,
 )
+from .metrics import add_span_error, setup_metrics
 from .operations import safe_send_channel
 from .services import ChannelsService, GuildsService, VerifiesService
 from .settings import Settings
@@ -56,6 +58,7 @@ class SpellBot(Bot):
         async with self.channel_locks[channel_xid]:  # type: ignore
             yield
 
+    @tracer.wrap()
     async def create_spelltable_link(self) -> Optional[str]:
         if self.mock_games:
             return f"http://exmaple.com/game/{uuid4()}"
@@ -93,6 +96,7 @@ class SpellBot(Bot):
                 hidden=True,
             )
 
+        add_span_error(ex)
         ref = (
             f"command `{ctx.name}`"
             if isinstance(ctx, context.SlashContext)
@@ -118,24 +122,43 @@ class SpellBot(Bot):
     async def on_slash_command_error(self, ctx: context.SlashContext, ex: Exception):
         return await self.handle_errors(ctx, ex)
 
+    @tracer.wrap(name="interaction", resource="on_message")
     async def on_message(self, message: discord.Message):
+        span = tracer.current_span()
+
+        # handle DMs normally
         if not message.guild or not hasattr(message.guild, "id"):
-            return await super().on_message(message)  # handle DMs normally
+            return await super().on_message(message)
+        span.set_tag("guild_id", message.guild.id)  # type: ignore
+
+        # ignore everything except messages in text channels
         if (
             not hasattr(message.channel, "type")
             or message.channel.type != discord.ChannelType.text
         ):
-            return  # ignore everything else, except messages in text channels...
+            return
+        span.set_tag("channel_id", message.channel.id)  # type: ignore
+
+        # ignore hidden or ephemeral messages
         if message.flags.value & 64:
-            return  # message is hidden, ignore it
+            return
+
+        # to verify users we need their user id
+        if not hasattr(message.author, "id"):
+            return
+
+        message_author_xid = message.author.id  # type: ignore
+        span.set_tag("author_id", message_author_xid)
+
+        # don't try to verify the bot itself
+        if self.user and message_author_xid == self.user.id:  # pragma: no cover
+            return
 
         async with db_session_manager():
             await self.handle_verification(message)
 
+    @tracer.wrap()
     async def handle_verification(self, message: discord.Message):
-        # To verify users we need their user id, so just give up if it's not available
-        if not hasattr(message.author, "id"):
-            return
         message_author_xid = message.author.id  # type: ignore
         verified: Optional[bool] = None
         guilds = GuildsService()
@@ -165,6 +188,8 @@ def build_bot(
 ) -> SpellBot:
     bot = SpellBot(loop=loop, mock_games=mock_games)
 
+    setup_metrics()
+
     # setup slash commands extension
     debug_guild: Optional[int] = None
     if bot.settings.DEBUG_GUILD:  # pragma: no cover
