@@ -4,6 +4,7 @@ import logging
 from typing import Optional
 
 import discord
+from ddtrace import tracer
 from discord.ext import commands
 from discord_slash import SlashContext, cog_ext
 from discord_slash.context import ComponentContext
@@ -11,6 +12,7 @@ from discord_slash.model import SlashCommandOptionType
 
 from .. import SpellBot
 from ..interactions import AdminInteraction
+from ..metrics import add_span_context
 from ..utils import for_all_callbacks, is_admin
 
 logger = logging.getLogger(__name__)
@@ -23,27 +25,37 @@ class AdminCog(commands.Cog):
         self.bot = bot
 
     @cog_ext.cog_slash(name="setup", description="Setup SpellBot on your server.")
+    @tracer.wrap(name="interaction", resource="setup")
     async def setup(self, ctx: SlashContext):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.setup()
 
     @cog_ext.cog_component()
+    @tracer.wrap(name="interaction", resource="refresh_setup")
     async def refresh_setup(self, ctx: ComponentContext):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.refresh_setup()
 
     @cog_ext.cog_component()
+    @tracer.wrap(name="interaction", resource="toggle_show_links")
     async def toggle_show_links(self, ctx: ComponentContext):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.toggle_show_links()
 
     @cog_ext.cog_component()
+    @tracer.wrap(name="interaction", resource="toggle_show_points")
     async def toggle_show_points(self, ctx: ComponentContext):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.toggle_show_points()
 
     @cog_ext.cog_component()
+    @tracer.wrap(name="interaction", resource="toggle_voice_create")
     async def toggle_voice_create(self, ctx: ComponentContext):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.toggle_voice_create()
 
@@ -60,7 +72,9 @@ class AdminCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="set_motd")
     async def motd(self, ctx: SlashContext, message: Optional[str] = None):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.set_motd(message)
 
@@ -77,7 +91,9 @@ class AdminCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="set_channel_motd")
     async def channel_motd(self, ctx: SlashContext, message: Optional[str] = None):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.set_channel_motd(message)
 
@@ -85,7 +101,9 @@ class AdminCog(commands.Cog):
         name="channels",
         description="Show the current configurations for channels on your server.",
     )
+    @tracer.wrap(name="interaction", resource="channels")
     async def channels(self, ctx: SlashContext):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.channels()
 
@@ -93,7 +111,9 @@ class AdminCog(commands.Cog):
         name="awards",
         description="Setup player awards on your server.",
     )
+    @tracer.wrap(name="interaction", resource="awards")
     async def awards(self, ctx: SlashContext):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.awards()
 
@@ -126,8 +146,15 @@ class AdminCog(commands.Cog):
                 "description": "Repeatedly give this award every X games?",
                 "type": SlashCommandOptionType.BOOLEAN.value,
             },
+            {
+                "name": "remove",
+                "required": False,
+                "description": "Instead of assigning the role, remove it from the player",
+                "type": SlashCommandOptionType.BOOLEAN.value,
+            },
         ],
     )
+    @tracer.wrap(name="interaction", resource="award_add")
     async def award_add(
         self,
         ctx: SlashContext,
@@ -135,9 +162,17 @@ class AdminCog(commands.Cog):
         role: discord.Role,
         message: str,
         repeating: Optional[bool] = False,
+        remove: Optional[bool] = False,
     ):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
-            await interaction.award_add(count, str(role), message, repeating)
+            await interaction.award_add(
+                count,
+                str(role),
+                message,
+                repeating=repeating,
+                remove=remove,
+            )
 
     @cog_ext.cog_subcommand(
         base="award",
@@ -152,7 +187,9 @@ class AdminCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="award_delete")
     async def award_delete(self, ctx: SlashContext, id: int):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.award_delete(id)
 
@@ -174,7 +211,9 @@ class AdminCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="set_default_seats")
     async def default_seats(self, ctx: SlashContext, seats: int):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.set_default_seats(seats)
 
@@ -191,7 +230,9 @@ class AdminCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="set_auto_verify")
     async def auto_verify(self, ctx: SlashContext, setting: bool):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.set_auto_verify(setting)
 
@@ -208,7 +249,9 @@ class AdminCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="set_verified_only")
     async def verified_only(self, ctx: SlashContext, setting: bool):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.set_verified_only(setting)
 
@@ -225,7 +268,9 @@ class AdminCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="set_unverified_only")
     async def unverified_only(self, ctx: SlashContext, setting: bool):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.set_unverified_only(setting)
 
@@ -241,7 +286,9 @@ class AdminCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="info")
     async def info(self, ctx: SlashContext, game_id: str):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.info(game_id)
 
@@ -258,7 +305,9 @@ class AdminCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="set_voice_category")
     async def voice_category(self, ctx: SlashContext, prefix: str):
+        add_span_context(ctx)
         async with AdminInteraction.create(self.bot, ctx) as interaction:
             await interaction.set_voice_category(prefix)
 
