@@ -1,10 +1,10 @@
 import logging
-import sys
-from os import getenv
 
+from ddtrace import tracer
 from discord.ext import commands, tasks
 
 from .. import SpellBot
+from ..environment import running_in_pytest
 from ..interactions import TaskInteraction
 from ..settings import Settings
 
@@ -15,14 +15,15 @@ settings = Settings()
 class TasksCog(commands.Cog):  # pragma: no cover
     def __init__(self, bot: SpellBot):
         self.bot = bot
-        if not getenv("PYTEST_CURRENT_TEST") and "pytest" not in sys.modules:
+        if not running_in_pytest():
             self.cleanup_old_voice_channels.start()
             self.expire_inactive_games.start()
 
     @tasks.loop(minutes=settings.VOICE_CLEANUP_LOOP_M)
     async def cleanup_old_voice_channels(self):
-        async with TaskInteraction.create(self.bot) as interaction:
-            await interaction.cleanup_old_voice_channels()
+        with tracer.trace(name="command", resource="cleanup_old_voice_channels"):
+            async with TaskInteraction.create(self.bot) as interaction:
+                await interaction.cleanup_old_voice_channels()
 
     @cleanup_old_voice_channels.before_loop
     async def before_cleanup_old_voice_channels(self):
@@ -30,8 +31,9 @@ class TasksCog(commands.Cog):  # pragma: no cover
 
     @tasks.loop(minutes=settings.EXPIRE_GAMES_LOOP_M)
     async def expire_inactive_games(self):
-        async with TaskInteraction.create(self.bot) as interaction:
-            await interaction.expire_inactive_games()
+        with tracer.trace(name="command", resource="expire_inactive_games"):
+            async with TaskInteraction.create(self.bot) as interaction:
+                await interaction.expire_inactive_games()
 
     @expire_inactive_games.before_loop
     async def before_expire_inactive_games(self):
