@@ -6,11 +6,13 @@ from dateutil import tz
 from discord.channel import VoiceChannel
 
 from .. import SpellBot
+from ..database import rollback_session
+from ..metrics import add_span_error
 from ..operations import (
     bot_can_delete_channel,
     safe_delete_channel,
-    safe_fetch_message,
     safe_fetch_text_channel,
+    safe_get_partial_message,
     safe_update_embed,
 )
 from ..services import GamesService
@@ -74,8 +76,10 @@ class TaskInteraction(BaseInteraction):
         try:
             channels = await self.gather_channels()
             await self.delete_channels(channels)
-        except BaseException as e:
+        except BaseException as e:  # Catch EVERYTHING so tasks don't die
+            add_span_error(e)
             logger.exception("error: exception in background task: %s", e)
+            await rollback_session()
 
     async def gather_channels(self) -> list[VoiceChannel]:
         channels: list[VoiceChannel] = []
@@ -126,8 +130,10 @@ class TaskInteraction(BaseInteraction):
         try:
             games = await self.services.games.inactive_games()
             await self.expire_games(games)
-        except BaseException as e:
+        except BaseException as e:  # Catch EVERYTHING so tasks don't die
+            add_span_error(e)
             logger.exception("error: exception in background task: %s", e)
+            await rollback_session()
 
     async def expire_games(self, games: list[dict]):
         game_ids = [game["id"] for game in games]
@@ -146,8 +152,7 @@ class TaskInteraction(BaseInteraction):
         if not chan:
             return
 
-        post = await safe_fetch_message(chan, guild_xid, message_xid)
-        if not post:
+        if not (post := safe_get_partial_message(chan, guild_xid, message_xid)):
             return
 
         await safe_update_embed(
