@@ -5,8 +5,7 @@ from sqlalchemy import BigInteger, Column, ForeignKey, Integer
 from .base import Base
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .guild import Guild  # noqa
-    from .user import User  # noqa
+    from . import Guild, User  # noqa
 
 
 class Config(Base):
