@@ -5,6 +5,7 @@ from typing import Optional
 
 import discord
 from asgiref.sync import sync_to_async
+from ddtrace import tracer
 from sqlalchemy import update
 from sqlalchemy.dialects.postgresql import insert
 from sqlalchemy.sql.expression import and_, asc, column, or_, select
@@ -27,11 +28,13 @@ class GamesService:
         self.game: Optional[Game] = None
 
     @sync_to_async
+    @tracer.wrap()
     def select(self, game_id: int) -> bool:
         self.game = DatabaseSession.query(Game).get(game_id)
         return bool(self.game)
 
     @sync_to_async
+    @tracer.wrap()
     def select_by_voice_xid(self, voice_xid: int) -> bool:
         self.game = (
             DatabaseSession.query(Game)
@@ -43,6 +46,7 @@ class GamesService:
         return bool(self.game)
 
     @sync_to_async
+    @tracer.wrap()
     def select_by_message_xid(self, message_xid: int) -> Optional[dict]:
         self.game = (
             DatabaseSession.query(Game)
@@ -54,6 +58,7 @@ class GamesService:
         return self.game.to_dict() if self.game else None
 
     @sync_to_async
+    @tracer.wrap()
     def add_player(self, player_xid: int) -> None:
         assert self.game
 
@@ -80,6 +85,7 @@ class GamesService:
         DatabaseSession.commit()
 
     @sync_to_async
+    @tracer.wrap()
     def upsert(
         self,
         *,
@@ -128,6 +134,7 @@ class GamesService:
         self.game = game
         return new
 
+    @tracer.wrap()
     def _find_existing(
         self,
         *,
@@ -139,6 +146,19 @@ class GamesService:
         format: int,
     ):
         required_seats = 1 + len(friends)
+        blockings = (
+            DatabaseSession.query(Block.blocked_user_xid)
+            .filter(
+                Block.user_xid.in_([User.xid, author_xid, *friends]),
+            )
+            .union(
+                DatabaseSession.query(Block.user_xid).filter(
+                    Block.blocked_user_xid.in_(
+                        [User.xid, author_xid, *friends],
+                    ),
+                ),
+            )
+        )
         inner = (
             select(
                 [
@@ -156,18 +176,13 @@ class GamesService:
                     Game.format == format,
                     Game.status == GameStatus.PENDING.value,
                     Game.deleted_at.is_(None),
+                    ~User.xid.in_(blockings),
                 ),
             )
             .group_by(Game, User.xid)
             .order_by(asc(Game.updated_at))
             .alias("inner")
         )
-        user_blocks = DatabaseSession.query(Block.blocked_user_xid).filter_by(
-            user_xid=author_xid,
-        )
-        blocks_user = DatabaseSession.query(Block.user_xid).filter_by(
-            blocked_user_xid=author_xid,
-        )
         outer = (
             DatabaseSession.query(Game)
             # Note: select_entity_from() is deprecated and may need to be replaced
@@ -179,8 +194,6 @@ class GamesService:
                     and_(
                         column("player_count") > 0,
                         column("player_count") <= seats - required_seats,
-                        ~inner.c.users_xid.in_(user_blocks),
-                        ~inner.c.users_xid.in_(blocks_user),
                     ),
                 ),
             )
@@ -188,23 +201,27 @@ class GamesService:
         return outer.first()
 
     @sync_to_async
+    @tracer.wrap()
     def to_embed(self, dm: bool = False) -> discord.Embed:
         assert self.game
         return self.game.to_embed(dm)
 
     @sync_to_async
+    @tracer.wrap()
     def set_message_xid(self, message_xid: int) -> None:
         assert self.game
         self.game.message_xid = message_xid  # type: ignore
         DatabaseSession.commit()
 
     @sync_to_async
+    @tracer.wrap()
     def fully_seated(self) -> bool:
         assert self.game
         rows = DatabaseSession.query(User).filter(User.game_id == self.game.id).count()
         return rows == self.game.seats
 
     @sync_to_async
+    @tracer.wrap()
     def make_ready(self, spelltable_link: Optional[str]) -> None:
         assert self.game
         assert len(spelltable_link or "") <= MAX_SPELLTABLE_LINK_LEN
@@ -214,12 +231,14 @@ class GamesService:
         DatabaseSession.commit()
 
     @sync_to_async
+    @tracer.wrap()
     def player_xids(self) -> list[int]:
         assert self.game
         rows = DatabaseSession.query(User.xid).filter(User.game_id == self.game.id)
         return [int(row[0]) for row in rows]
 
     @sync_to_async
+    @tracer.wrap()
     def watch_notes(self, player_xids: list[int]) -> dict[int, Optional[str]]:
         assert self.game
         watched = (
@@ -235,6 +254,7 @@ class GamesService:
         return {watch.user_xid: watch.note for watch in watched}
 
     @sync_to_async
+    @tracer.wrap()
     def record_plays(self) -> None:
         assert self.game
         assert self.game.status == GameStatus.STARTED.value
@@ -272,6 +292,7 @@ class GamesService:
         DatabaseSession.commit()
 
     @sync_to_async
+    @tracer.wrap()
     def set_voice(self, voice_xid: int, voice_invite_link: str) -> None:
         assert self.game
         assert len(voice_invite_link or "") <= MAX_VOICE_INVITE_LINK_LEN
@@ -280,7 +301,9 @@ class GamesService:
         DatabaseSession.commit()
 
     @sync_to_async
-    def filter_blocked(self, author_xid: int, other_xids: list[int]) -> list[int]:
+    @tracer.wrap()
+    def filter_blocked_list(self, author_xid: int, other_xids: list[int]) -> list[int]:
+        """Given an author, filters out any blocked players from a list of others."""
         blockers = (
             DatabaseSession.query(Block)
             .filter(
@@ -304,6 +327,7 @@ class GamesService:
         )
 
     @sync_to_async
+    @tracer.wrap()
     def blocked(self, author_xid: int) -> bool:
         assert self.game
         rows = DatabaseSession.query(User.xid).filter(User.game_id == self.game.id)
@@ -324,6 +348,7 @@ class GamesService:
         return bool(DatabaseSession.query(query.exists()).scalar())
 
     @sync_to_async
+    @tracer.wrap()
     def players_included(self, player_xid: int) -> bool:
         """
         Players that played this game.
@@ -344,6 +369,7 @@ class GamesService:
         return bool(record)
 
     @sync_to_async
+    @tracer.wrap()
     def add_points(self, player_xid: int, points: int):
         assert self.game
         values = {
@@ -364,11 +390,13 @@ class GamesService:
         DatabaseSession.commit()
 
     @sync_to_async
+    @tracer.wrap()
     def to_dict(self) -> dict:
         assert self.game
         return self.game.to_dict()
 
     @sync_to_async
+    @tracer.wrap()
     def inactive_games(self) -> list[dict]:
         settings = Settings()
         limit = datetime.utcnow() - timedelta(minutes=settings.EXPIRE_TIME_M)
@@ -382,6 +410,7 @@ class GamesService:
         return [record.to_dict() for record in records]
 
     @sync_to_async
+    @tracer.wrap()
     def delete_games(self, game_ids: list[int]):
         DatabaseSession.execute(
             update(Game)
