@@ -3,6 +3,7 @@ from contextlib import AbstractContextManager
 from typing import Any, Optional, Union, cast
 
 import discord
+from ddtrace import tracer
 from discord_slash.context import InteractionContext
 from discord_slash.model import CallbackObject
 
@@ -155,6 +156,8 @@ class suppress(AbstractContextManager):
         pass
 
     def __exit__(self, exctype, excinst, exctb):
+        if span := tracer.current_span():  # pragma: no cover
+            span.set_exc_info(exctype, excinst, exctb)
         if captured := exctype is not None and issubclass(exctype, self._exceptions):
             log_warning(self._log, exec_info=True, **self._kwargs)
         return captured
